@@ -17,6 +17,7 @@ from collections import deque
 from typing import Optional
 
 from google.api_core.exceptions import FailedPrecondition
+
 from google.cloud.pubsublite.cloudpubsub.internal.ack_set_tracker import AckSetTracker
 from google.cloud.pubsublite.internal.wire.committer import Committer
 from google.cloud.pubsublite_v1 import Cursor
@@ -43,9 +44,7 @@ class AckSetTrackerImpl(AckSetTracker):
                 )
         self._receipts.append(offset)
 
-    async def ack(self, offset: int):
-        # Note: put_nowait is used here and below to ensure that the below logic is executed without yielding
-        # to another coroutine in the event loop. The queue is unbounded so it will never throw.
+    def ack(self, offset: int):
         self._acks.put_nowait(offset)
         prefix_acked_offset: Optional[int] = None
         while len(self._receipts) != 0 and not self._acks.empty():
@@ -60,7 +59,7 @@ class AckSetTrackerImpl(AckSetTracker):
         if prefix_acked_offset is None:
             return
         # Convert from last acked to first unacked.
-        await self._committer.commit(Cursor(offset=prefix_acked_offset + 1))
+        self._committer.commit(Cursor(offset=prefix_acked_offset + 1))
 
     async def clear_and_commit(self):
         self._receipts.clear()
